Walk

Struct Walk 

pub struct Walk {
    pub paths: Vec<PathBuf>,
    pub output: Option<Vec<PathBuf>>,
    pub recursive: bool,
    pub hidden: bool,
    pub no_ignore: bool,
    pub threads: usize,
    pub quiet: bool,
}
This will iterate over a set of paths.

Fields

paths: Vec<PathBuf>

The set of paths to visit

output: Option<Vec<PathBuf>>

Whether to write to the specified file or directory. Will use the input if flag is given without a value. Defaults to standard output.

recursive: bool

If the path is a directory, whether to walk through and process its subdirectories

hidden: bool

Whether to search through hidden files and directories.

A file or directory is considered hidden if its base name starts with a ‘.’ or if the operating system provides a “hidden” file attribute.

Ignored files will continue to be skipped and can be enabled with the --no-ignore flag.

no_ignore: bool

When set, patterns defined in files such as .gitigore will be disregarded.

Hidden files will continue to be skipped and can be enabled with the --hidden flag.

threads: usize

Sets the approximate number of threads to use. A value of 0 (default) will automatically determine the appropriate number

quiet: bool

Suppresses info logging

Implementations

Source

impl Walk

pub fn run<F: Fn() -> Box<dyn FnMut(&str, Option<&PathBuf>, Option<&PathBuf>) + Send>>( &self, f: F, ) -> Result<()>

Start visiting the paths in parallel. f is called for each thread and the resulting function is called for each path.

Errors

When invalid options are passed to Walk.