pub struct Walk {
pub paths: Vec<PathBuf>,
pub output: Option<Vec<PathBuf>>,
pub recursive: bool,
pub hidden: bool,
pub no_ignore: bool,
pub threads: usize,
pub quiet: bool,
}Expand description
This will iterate over a set of paths.
Fields
paths: Vec<PathBuf>The set of paths to visit
output: Option<Vec<PathBuf>>Whether to write to the specified file or directory. Will use the input if flag is given without a value. Defaults to standard output.
recursive: boolIf the path is a directory, whether to walk through and process its subdirectories
Whether to search through hidden files and directories.
A file or directory is considered hidden if its base name starts with a ‘.’ or if the operating system provides a “hidden” file attribute.
Ignored files will continue to be skipped and can be enabled with the --no-ignore flag.
no_ignore: boolWhen set, patterns defined in files such as .gitigore will be disregarded.
Hidden files will continue to be skipped and can be enabled with the --hidden flag.
threads: usizeSets the approximate number of threads to use. A value of 0 (default) will automatically determine the appropriate number
quiet: boolSuppresses info logging
Implementations